<?php

namespace Drupal\purencool_vision_configuration\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a 'PurencoolAllContactInformationBlock' block.
 *
 * @Block(
 *  id = "purencool_all_contact_information_block",
 *  admin_label = @Translation("Purencool all contact information block"),
 * )
 */
class PurencoolAllContactInformationBlock extends BlockBase
{

  /**
   *  Returns Email links if they are set in theme settings
   * @return string
   */
  private function email()
  {
    $email = theme_get_setting('email');
    if ($email) {
      return '<div id="email-content" class="all-contact-information-item">
                <a href="mail:' . $email . '" class="a-envelope">' . $email . '</a>
              </div>';
    }
    return '';
  }

  /**
   * Returns Phone number links if they are set in theme settings
   * @return string
   */
  private function phone()
  {
    $phone = theme_get_setting('phone');
    if ($phone) {
      return '<div id="phone-content" class="all-contact-information-item">
                <a href="phone:' . $phone . '" class="a-phone">' . $phone . '</a>
              </div>';
    }
    return '';
  }

  /**
   * Returns Address if they are set in theme settings
   * @return string
   */
  private function address()
  {
    $address = theme_get_setting('address');
    if ($address) {
      return '<div id="address-content" class="all-contact-information-item"><pre>' .
        $address
        . '</pre></div>';
    }
    return '';
  }


  /**
   *  Returns Contact Title links if they are set in theme settings
   * @return string
   */
  private function contact_title()
  {
    $contact_title = theme_get_setting('contact_title');
    if ($contact_title) {
      return '<div id="contact-title-content" class="all-contact-information-title">' .
        $contact_title
        . '</div>';
    }
    return '';
  }


  /**
   * Returns Social media links if they are set in theme settings
   * @return string
   */
  private function socialMedia()
  {
    $facebook_url = theme_get_setting('facebook_url');
    $twitter_url = theme_get_setting('twitter_url');
    $linkedin_url = theme_get_setting('linkedin_url');
    $instagram_url = theme_get_setting('instagram_url');

    if ($facebook_url || $twitter_url || $linkedin_url) {
      $output = '<div id="contact-services-links all-contact-information-item">';
      $output .= '<div class="content">';
      $output .= '<div class=social-icons>';

      if ($facebook_url) {
        $output .= '<a href="' . $facebook_url . '" class="a-facebook" target="_blank"><i class="fa fa-facebook-square fa-lg"></i></a>';
      }
      if ($instagram_url) {
        $output .= '<a href="' . $instagram_url . '" class="a-instagram" target="_blank"><i class="fa fa-instagram fa-lg"></i></a>';
      }

      if ($twitter_url) {
        $output .= '<a href="' . $twitter_url . '" class="a-twitter" target="_blank"><i class="fa fa-twitter-square fa-lg"></i></a>';
      }
      if ($linkedin_url) {
        $output .= ' <a href="' . $linkedin_url . '" class="a-linkedin" target="_blank"><i class="fa fa-linkedin-square fa-lg"></i></a>';
      }

      $output .= '</div>';
      $output .= '</div>';
      $output .= '</div>';

      return $output;
    }
    return '';

  }

  /**
   * {@inheritdoc}
   */
  public function build()
  {
    /**
     * @todo turn the theme_settings into OOP remove function
     */

    $social = $this->socialMedia();
    $email = $this->email();
    $phone = $this->phone();
    $address = $this->address();

    $returnInformation = $social . $email . $phone . $address;
    $output = '<div class="block-all-contact-information full-page-width-item">';
    $output .= '<div class="all-contact-information">';

    if ($returnInformation === '') {
      $output .= t('This block needs information to be set inside the theme settings under contact');
    } else {
      //@todo this needs to be added to a template
      $output .= '<div><h2>Phone & Email</h2>';
      $output .=  $phone.$email;
      $output .=  '</div>';
      $output .= '<div><h2>Address</h2>';
      $output .=  $address;
      $output .=  '</div>';
      $output .= '<div><h2>Follow Me</h2>';
      $output .=  $social;
      $output .=  '</div>';
    }

    $output .= '</div>';
    $output .= '</div>';

    $build = [];
    $build['#theme'] = 'default_block';
    $build['default_block']['#markup'] = $output;

    return $build;
  }

}
